# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.experiments_.post import ExperimentsCreate
from galv.paths.experiments_uuid_.delete import ExperimentsDestroy
from galv.paths.experiments_.get import ExperimentsList
from galv.paths.experiments_uuid_.patch import ExperimentsPartialUpdate
from galv.paths.experiments_uuid_.get import ExperimentsRetrieve


class ExperimentsApi(
    ExperimentsCreate,
    ExperimentsDestroy,
    ExperimentsList,
    ExperimentsPartialUpdate,
    ExperimentsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
