# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.teams_.post import TeamsCreate
from galv.paths.teams_id_.delete import TeamsDestroy
from galv.paths.teams_.get import TeamsList
from galv.paths.teams_id_.patch import TeamsPartialUpdate
from galv.paths.teams_id_.get import TeamsRetrieve


class TeamsApi(
    TeamsCreate,
    TeamsDestroy,
    TeamsList,
    TeamsPartialUpdate,
    TeamsRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
