# coding: utf-8

"""
    Battery Data API

    A standard API for accessing battery experiment datasets and metadata  # noqa: E501

    The version of the OpenAPI document: 2.1.20
    Contact: martin.robinson@cs.ox.ac.uk
    Generated by: https://openapi-generator.tech
"""

from galv.paths.schedule_families_.post import ScheduleFamiliesCreate
from galv.paths.schedule_families_uuid_.delete import ScheduleFamiliesDestroy
from galv.paths.schedule_families_.get import ScheduleFamiliesList
from galv.paths.schedule_families_uuid_.patch import ScheduleFamiliesPartialUpdate
from galv.paths.schedule_families_uuid_.get import ScheduleFamiliesRetrieve


class ScheduleFamiliesApi(
    ScheduleFamiliesCreate,
    ScheduleFamiliesDestroy,
    ScheduleFamiliesList,
    ScheduleFamiliesPartialUpdate,
    ScheduleFamiliesRetrieve,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
